@@ -27,8 +27,9 @@
 #include "sharewidget.h"
 #include "connectionwidget.h"
 #include "settingswidget.h"
+#include "mediawidget.h"
 
-EditConnectionDialog::EditConnectionDialog ( QString id, QWidget * par,
+EditConnectionDialog::EditConnectionDialog ( bool newSession, QString id, QWidget * par,
         int ind,Qt::WFlags f )
         : QDialog ( par,f )
 {
@@ -49,14 +50,16 @@ EditConnectionDialog::EditConnectionDialog ( QString id, QWidget * par,
 #endif
     setFont ( fnt );
 
-    sessSet=new SessionWidget ( id,parent );
+    sessSet=new SessionWidget ( newSession, id,parent );
     conSet=new ConnectionWidget ( id,parent );
     otherSet=new SettingsWidget ( id,parent );
+    mediaSet=new MediaWidget ( id,parent );
     exportDir=new ShareWidget ( id,parent );
 
     fr->addTab ( sessSet,tr ( "&Session" ) );
     fr->addTab ( conSet,tr ( "&Connection" ) );
-    fr->addTab ( otherSet,tr ( "&Settings" ) );
+    fr->addTab ( otherSet,tr ( "&Input/Output" ) );
+    fr->addTab ( mediaSet,tr ( "&Media" ) );
     if (! parent->getHideFolderSharing())
         fr->addTab ( exportDir,tr ( "&Shared folders" ) );
 
@@ -129,6 +132,7 @@ void EditConnectionDialog::slot_accepted()
     conSet->saveSettings();
     exportDir->saveSettings();
     otherSet->saveSettings();
+    mediaSet->saveSettings();
     sessSet->saveSettings();
 }
 
@@ -153,6 +157,11 @@ void EditConnectionDialog::slot_default()
     }
     break;
     case 3:
+    {
+        mediaSet->setDefaults();
+    }
+    break;
+    case 4:
     {
         exportDir->setDefaults();
     }
@@ -165,6 +174,7 @@ void EditConnectionDialog::slot_directRDP(bool direct)
 {
     fr->setTabEnabled(1,!direct);
     fr->setTabEnabled(3,!direct);
+    fr->setTabEnabled(4,!direct);
     otherSet->setDirectRdp(direct);
 }
 #endif
