@@ -41,29 +41,31 @@ class QTreeView;
 class SessionWidget;
 class ConnectionWidget;
 class SettingsWidget;
+class MediaWidget;
 class ShareWidget;
 
 class EditConnectionDialog : public QDialog
 {
-		Q_OBJECT
-	public:
-		EditConnectionDialog ( QString id, QWidget * par,  int ind=0,
-		                       Qt::WFlags f = 0 );
-		~EditConnectionDialog();
-	private:
-		QTabWidget *fr;
-		SessionWidget* sessSet;
-		ConnectionWidget* conSet;
-		SettingsWidget* otherSet;
-		ShareWidget* exportDir;
+    Q_OBJECT
+public:
+    EditConnectionDialog ( bool newSession, QString id, QWidget * par,  int ind=0,
+                           Qt::WFlags f = 0 );
+    ~EditConnectionDialog();
+private:
+    QTabWidget *fr;
+    SessionWidget* sessSet;
+    ConnectionWidget* conSet;
+    SettingsWidget* otherSet;
+    MediaWidget* mediaSet;
+    ShareWidget* exportDir;
 
 
-	private slots:
-		void slot_changeCaption ( const QString& newName );
-		void slot_accepted();
-		void slot_default();
-#ifdef Q_OS_LINUX		
-		void slot_directRDP(bool direct);
+private slots:
+    void slot_changeCaption ( const QString& newName );
+    void slot_accepted();
+    void slot_default();
+#ifdef Q_OS_LINUX
+    void slot_directRDP(bool direct);
 #endif
 };
 
