@@ -80,6 +80,8 @@ class QStandardItemModel;
 class HttpBrokerClient;
 class QMenu;
 class QComboBox;
+
+class SessionExplorer;
 struct user
 {
     int uin;
@@ -339,10 +341,6 @@ public:
     ~ONMainWindow();
     static void installTranslator();
     QString iconsPath ( QString fname );
-    const QList<SessionButton*> * getSessionsList()
-    {
-        return &sessions;
-    }
     static bool isServerRunning ( int port );
     void startNewSession();
     void suspendSession ( QString sessId );
@@ -425,6 +423,10 @@ public:
     {
         return defaultSshPort;
     }
+    QString getDefaultClipboardMode()
+    {
+        return defaultClipboardMode;
+    }
     QString getDefaultKbdType()
     {
         return defaultKbdType;
@@ -498,6 +500,41 @@ public:
         return hideFolderSharing;
     }
 
+    SessionExplorer* getSessionExplorer()
+    {
+        return sessionExplorer;
+    }
+
+    bool getBrokerMode()
+    {
+        return brokerMode;
+    }
+
+    bool getMiniMode()
+    {
+        return miniMode;
+    }
+
+    QScrollArea* getUsersArea()
+    {
+        return users;
+    }
+
+    QFrame* getUsersFrame()
+    {
+        return uframe;
+    }
+
+    IMGFrame* getCentralFrame()
+    {
+        return fr;
+    }
+
+    ConfigFile* getConfig()
+    {
+        return &config;
+    }
+
     void runApplication(QString exec);
 
 
@@ -599,6 +636,7 @@ private:
     QStringList defaultLayout;
     QString selectedLayout;
     QString defaultKbdType;
+    QString defaultClipboardMode;
     QString defaultCmd;
     bool defaultSetDPI;
     uint defaultDPI;
@@ -626,6 +664,8 @@ private:
     QLineEdit* desktopFilter;
     QCheckBox* desktopFilterCb;
 
+    SessionExplorer* sessionExplorer;
+
     IMGFrame* fr;
     SVGFrame *bgFrame;
     QLineEdit* uname;
@@ -665,9 +705,7 @@ private:
     QHBoxLayout* mainL;
     QHBoxLayout* bgLay;
     QList<UserButton*> names;
-    QList<SessionButton*> sessions;
     UserButton* lastUser;
-    SessionButton* lastSession;
     QString prevText;
     QString onserver;
     QString id;
@@ -876,8 +914,6 @@ private:
     QString defaultSessionId;
     QString defaultUserName;
     bool defaultUser;
-    SessionButton* createBut ( const QString& id );
-    void placeButtons();
     QString getKdeIconsPath();
     QString findTheme ( QString theme );
     bool initLdapSession ( bool showBox=true );
@@ -888,6 +924,7 @@ private:
     x2goSession getSelectedSession();
     bool parseParameter ( QString param );
     bool linkParameter ( QString value );
+    bool clipboardParameter ( QString value );
     bool geometry_par ( QString value );
     bool setKbd_par ( QString value );
     bool ldapParameter ( QString value );
@@ -973,10 +1010,6 @@ private slots:
 public slots:
     void slotConfig();
     void slotNewSession();
-    void slotDeleteButton ( SessionButton * bt );
-    void slotEdit ( SessionButton* );
-    void slotCreateDesktopIcon ( SessionButton* bt );
-    void exportsEdit ( SessionButton* bt );
     void slotEmbedControlAction();
     void slotDetachProxyWindow();
     void slotActivateWindow();
