@@ -33,10 +33,11 @@
 #include "x2gologdebug.h"
 #include <QApplication>
 #include <QDesktopWidget>
+#include "sessionexplorer.h"
 
 
 SessionButton::SessionButton ( ONMainWindow* mw,QWidget *parent, QString id )
-        : SVGFrame ( ":/svg/sessionbut.svg",false,parent )
+    : SVGFrame ( ":/svg/sessionbut.svg",false,parent )
 {
     editable=mw->sessionEditEnabled();
 
@@ -285,11 +286,19 @@ void SessionButton::redraw()
     else
         st= new X2goSettings( "sessions" );
 
+    QString name=st->setting()->value ( sid+"/name",
+                                        ( QVariant ) tr ( "New Session" ) ).toString();
 
+    QStringList tails=name.split("/",QString::SkipEmptyParts);
+    if(tails.count()>0)
+    {
+        name=tails.last();
+        tails.pop_back();
+        path=tails.join("/");
+    }
+
+    sessName->setText (name);
 
-    sessName->setText (
-        st->setting()->value ( sid+"/name",
-                               ( QVariant ) tr ( "New Session" ) ).toString());
     QString status=st->setting()->value ( sid+"/status",
                                           ( QVariant ) QString::null ).toString();
     if (status == "R")
@@ -333,7 +342,7 @@ void SessionButton::redraw()
     QString command=st->setting()->value ( sid+"/command",
                                            ( QVariant )
                                            tr (
-                                               "KDE" ) ).
+                                                   "KDE" ) ).
                     toString();
     rootless=st->setting()->value ( sid+"/rootless",
                                     false ).toBool();
@@ -348,6 +357,10 @@ void SessionButton::redraw()
     cmdBox->addItem ( "XFCE" );
     cmdBox->addItem ( "MATE" );
     cmdBox->addItem ( "UNITY" );
+    cmdBox->addItem ( "CINNAMON" );
+    cmdBox->addItem ( "TRINITY" );
+    cmdBox->addItem ( "OPENBOX" );
+    cmdBox->addItem ( "ICEWM" );
     cmdBox->addItem ( tr ( "RDP connection" ) );
     cmdBox->addItem ( tr ( "XDMCP" ) );
     cmdBox->addItem ( tr ( "Connection to local desktop" ) );
@@ -387,6 +400,26 @@ void SessionButton::redraw()
         cmdpix.load ( par->iconsPath ( "/16x16/lxde.png" ) );
         cmdBox->setCurrentIndex ( LXDE );
     }
+    else if ( command == "CINNAMON" )
+    {
+        cmdpix.load ( par->iconsPath ( "/16x16/cinnamon.png" ) );
+        cmdBox->setCurrentIndex ( CINNAMON );
+    }
+    else if ( command == "TRINITY" )
+    {
+        cmdpix.load ( par->iconsPath ( "/16x16/trinity.png" ) );
+        cmdBox->setCurrentIndex ( TRINITY );
+    }
+    else if ( command == "OPENBOX" )
+    {
+        cmdpix.load ( par->iconsPath ( "/16x16/openbox.png" ) );
+        cmdBox->setCurrentIndex ( OPENBOX );
+    }
+    else if ( command == "ICEWM" )
+    {
+        cmdpix.load ( par->iconsPath ( "/16x16/icewm.png" ) );
+        cmdBox->setCurrentIndex ( ICEWM );
+    }
     else if ( command =="SHADOW" )
     {
         cmdpix.load ( par->iconsPath ( "/16x16/X.png" ) );
@@ -438,7 +471,7 @@ void SessionButton::redraw()
     geomBox->addItem ( tr ( "fullscreen" ) );
     uint displays=QApplication::desktop()->numScreens();
     if (!directRDP)
-        for (uint i=0;i<displays;++i)
+        for (uint i=0; i<displays; ++i)
         {
             geomBox->addItem ( tr( "Display " )+QString::number(i+1));
 
@@ -462,43 +495,42 @@ void SessionButton::redraw()
     {
         geom->setText ( tr ( "fullscreen" ) );
     }
-    else
-        if (st->setting()->value ( sid+"/multidisp",
-                                   ( QVariant ) false ).toBool() && !directRDP)
+    else if (st->setting()->value ( sid+"/multidisp",
+                                    ( QVariant ) false ).toBool() && !directRDP)
+    {
+        uint disp=st->setting()->value ( sid+"/display",
+                                         ( QVariant ) 1 ).toUInt();
+        if (disp<=displays)
         {
-            uint disp=st->setting()->value ( sid+"/display",
-                                             ( QVariant ) 1 ).toUInt();
-            if (disp<=displays)
-            {
-                geom->setText( tr( "Display " )+QString::number(disp));
-            }
-            else
-            {
-                geom->setText( tr( "Display " )+QString::number(1));
-            }
-            for (int i=0;i<geomBox->count();++i)
-                if (geomBox->itemText(i)==geom->text())
-                {
-                    geomBox->setCurrentIndex(i);
-                    break;
-                }
+            geom->setText( tr( "Display " )+QString::number(disp));
         }
         else
         {
-#ifndef	Q_WS_HILDON
-            QString g=QString::number ( st->setting()->value (
-                                            sid+"/width" ).toInt() );
-            g+="x"+QString::number ( st->setting()->value (
-                                         sid+"/height" ).toInt() );
-            geom->setText ( g );
-            if ( geomBox->findText ( g ) ==-1 )
-                geomBox->addItem ( g );
-            geomBox->setCurrentIndex ( geomBox->findText ( g ) );
-#else
-            geom->setText ( tr ( "window" ) );
-            geomBox->setCurrentIndex ( 1 );
-#endif
+            geom->setText( tr( "Display " )+QString::number(1));
         }
+        for (int i=0; i<geomBox->count(); ++i)
+            if (geomBox->itemText(i)==geom->text())
+            {
+                geomBox->setCurrentIndex(i);
+                break;
+            }
+    }
+    else
+    {
+#ifndef	Q_WS_HILDON
+        QString g=QString::number ( st->setting()->value (
+                                        sid+"/width" ).toInt() );
+        g+="x"+QString::number ( st->setting()->value (
+                                     sid+"/height" ).toInt() );
+        geom->setText ( g );
+        if ( geomBox->findText ( g ) ==-1 )
+            geomBox->addItem ( g );
+        geomBox->setCurrentIndex ( geomBox->findText ( g ) );
+#else
+        geom->setText ( tr ( "window" ) );
+        geomBox->setCurrentIndex ( 1 );
+#endif
+    }
 
     if (directRDP)
     {
@@ -695,6 +727,28 @@ void SessionButton::slot_cmd_change ( const QString& command )
         newRootless=false;
         pix.load ( par->iconsPath ( "/16x16/mate.png" ) );
     }
+    else if ( command == "CINNAMON" )
+    {
+        newRootless=false;
+        // As of 2014-10-01, Cinnamon does not have a logo. This icon is the
+        // gear, which is the default start menu icon as of 2.2.
+        pix.load ( par->iconsPath ( "/16x16/cinnamon.png" ) );
+    }
+    else if ( command == "TRINITY" )
+    {
+        newRootless=false;
+        pix.load ( par->iconsPath ( "/16x16/trinity.png" ) );
+    }
+    else if ( command == "OPENBOX" )
+    {
+        newRootless=false;
+        pix.load ( par->iconsPath ( "/16x16/openbox.png" ) );
+    }
+    else if ( command == "ICEWM" )
+    {
+        newRootless=false;
+        pix.load ( par->iconsPath ( "/16x16/icewm.png" ) );
+    }
     else if ( command ==tr ( "Connection to local desktop" ) )
     {
         newRootless=false;
@@ -748,6 +802,11 @@ void SessionButton::slot_cmd_change ( const QString& command )
         cmd="MATE";
         newRootless=false;
     }
+    if ( command=="cinnamon-session" )
+    {
+        cmd="CINNAMON";
+        newRootless=false;
+    }
     if (command== tr("Published applications"))
     {
         published=true;
@@ -781,29 +840,28 @@ void SessionButton::slot_geom_change ( const QString& new_g )
         st.setting()->setValue ( sid+"/multidisp", ( QVariant ) false );
         st.setting()->setValue ( sid+"/maxdim", ( QVariant ) true );
     }
+    else if (new_g.indexOf(tr("Display "))==0)
+    {
+        QString g= new_g;
+        g.replace(tr("Display "),"");
+        st.setting()->setValue ( sid+"/multidisp", ( QVariant ) true );
+        st.setting()->setValue ( sid+"/display", ( QVariant ) g.toUInt());
+        st.setting()->setValue ( sid+"/fullscreen", ( QVariant ) false );
+        st.setting()->setValue ( sid+"/maxdim", ( QVariant ) false );
+    }
     else
-        if (new_g.indexOf(tr("Display "))==0)
-        {
-            QString g= new_g;
-            g.replace(tr("Display "),"");
-            st.setting()->setValue ( sid+"/multidisp", ( QVariant ) true );
-            st.setting()->setValue ( sid+"/display", ( QVariant ) g.toUInt());
-            st.setting()->setValue ( sid+"/fullscreen", ( QVariant ) false );
-            st.setting()->setValue ( sid+"/maxdim", ( QVariant ) false );
-        }
-        else
-        {
-            QString new_geom=new_g;
+    {
+        QString new_geom=new_g;
 #ifdef Q_WS_HILDON
-            new_geom="800x600";
+        new_geom="800x600";
 #endif
-            st.setting()->setValue ( sid+"/fullscreen", ( QVariant ) false );
-            st.setting()->setValue ( sid+"/multidisp", ( QVariant ) false );
-            st.setting()->setValue ( sid+"/maxdim", ( QVariant ) false );
-            QStringList lst=new_geom.split ( 'x' );
-            st.setting()->setValue ( sid+"/width", ( QVariant ) lst[0] );
-            st.setting()->setValue ( sid+"/height", ( QVariant ) lst[1] );
-        }
+        st.setting()->setValue ( sid+"/fullscreen", ( QVariant ) false );
+        st.setting()->setValue ( sid+"/multidisp", ( QVariant ) false );
+        st.setting()->setValue ( sid+"/maxdim", ( QVariant ) false );
+        QStringList lst=new_geom.split ( 'x' );
+        st.setting()->setValue ( sid+"/width", ( QVariant ) lst[0] );
+        st.setting()->setValue ( sid+"/height", ( QVariant ) lst[1] );
+    }
     st.setting()->sync();
 }
 
@@ -835,5 +893,5 @@ void SessionButton::slotShowMenu()
 
 void SessionButton::slotCreateSessionIcon()
 {
-    par->slotCreateDesktopIcon ( this );
+    par->getSessionExplorer()->slotCreateDesktopIcon ( this );
 }
