@@ -32,7 +32,7 @@ class SessionButton : public SVGFrame
 {
     Q_OBJECT
 public:
-    enum {KDE,GNOME,LXDE,XFCE,MATE,UNITY,RDP,XDMCP,SHADOW,PUBLISHED,OTHER,APPLICATION};
+    enum {KDE,GNOME,LXDE,XFCE,MATE,UNITY,CINNAMON,TRINITY,OPENBOX,ICEWM,RDP,XDMCP,SHADOW,PUBLISHED,OTHER,APPLICATION};
     SessionButton ( ONMainWindow* mw, QWidget* parent,QString id );
     ~SessionButton();
     QString id() {
@@ -44,8 +44,18 @@ public:
     }
     static bool lessThen ( const SessionButton* b1, const SessionButton* b2 );
     QString name();
+    QString getPath()
+    {
+        return path;
+    }
+    void setPath(QString path)
+    {
+        this->path=path;
+    }
+
 private:
     QString sid;
+    QString path;
     QLabel* sessName;
     QLabel* sessStatus;
     QLabel* icon;
