@@ -20,7 +20,8 @@
 #include "x2goclientconfig.h"
 
 #include <QDialog>
-class QListView;
+class QTreeWidget;
+class QTreeWidgetItem;
 class QPushButton;
 class QModelIndex;
 class ONMainWindow;
@@ -30,26 +31,29 @@ class ONMainWindow;
 
 class SessionManageDialog : public QDialog
 {
-		Q_OBJECT
-	public:
-		SessionManageDialog ( QWidget * parent,
-		                      bool onlyCreateIcon=false,
-		                      Qt::WFlags f=0 );
-		~SessionManageDialog();
-		void loadSessions();
-	private:
-		QListView* sessions;
-		QPushButton* editSession;
-		QPushButton* removeSession;
-		QPushButton* createSessionIcon;
-		ONMainWindow* par;
-	private slots:
-		void slot_activated ( const QModelIndex& index );
-		void slotNew();
-		void slot_edit();
-		void slot_createSessionIcon();
-		void slot_delete();
-		void slot_dclicked ( const QModelIndex& index );
+    Q_OBJECT
+public:
+    SessionManageDialog ( QWidget * parent,
+                          bool onlyCreateIcon=false,
+                          Qt::WFlags f=0 );
+    ~SessionManageDialog();
+    void loadSessions();
+private:
+    void initFolders(QTreeWidgetItem* parent, QString path);
+private:
+    QTreeWidget* sessions;
+    QPushButton* editSession;
+    QPushButton* removeSession;
+    QPushButton* createSessionIcon;
+    ONMainWindow* par;
+    QString currentPath;
+private slots:
+    void slot_activated ( QTreeWidgetItem * item, int);
+    void slotNew();
+    void slot_edit();
+    void slot_createSessionIcon();
+    void slot_delete();
+    void slot_dclicked ( QTreeWidgetItem * item, int );
 };
 
 #endif
