@@ -35,8 +35,10 @@
 #include <QMessageBox>
 #include <QButtonGroup>
 #include <QRadioButton>
+#include "folderexplorer.h"
+#include "sessionexplorer.h"
 
-SessionWidget::SessionWidget ( QString id, ONMainWindow * mw,
+SessionWidget::SessionWidget ( bool newSession, QString id, ONMainWindow * mw,
                                QWidget * parent, Qt::WindowFlags f )
     : ConfigWidget ( id,mw,parent,f )
 {
@@ -44,6 +46,9 @@ SessionWidget::SessionWidget ( QString id, ONMainWindow * mw,
 #ifdef Q_WS_HILDON
     sessLay->setMargin ( 2 );
 #endif
+    this->parent=mw;
+    this->newSession=newSession;
+
     sessName=new QLineEdit ( this );
     icon=new QPushButton ( QString::null,this );
     if ( !miniMode )
@@ -66,6 +71,14 @@ SessionWidget::SessionWidget ( QString id, ONMainWindow * mw,
     ilay->addWidget ( icon );
     ilay->addWidget ( new QLabel ( tr ( "<< change icon" ),this ) );
 
+    lPath=new QLabel(this);
+    lPath->setFrameStyle(QFrame::StyledPanel);
+    QPushButton* pathButton=new QPushButton("...",this);
+    QHBoxLayout* pathLay=new QHBoxLayout();
+    pathLay->addWidget(new QLabel(tr("Path:"), this),0);
+    pathLay->addWidget(lPath,1);
+    pathLay->addWidget(pathButton,0);
+
 #ifndef Q_WS_HILDON
     QGroupBox *sgb=new QGroupBox ( tr ( "&Server" ),this );
 #else
@@ -196,6 +209,10 @@ SessionWidget::SessionWidget ( QString id, ONMainWindow * mw,
     sessBox->addItem ( "XFCE" );
     sessBox->addItem ( "MATE" );
     sessBox->addItem ( "UNITY" );
+    sessBox->addItem ( "CINNAMON" );
+    sessBox->addItem ( "TRINITY" );
+    sessBox->addItem ( "OPENBOX" );
+    sessBox->addItem ( "ICEWM" );
     sessBox->addItem ( tr ( "Connect to Windows terminal server" ) );
     sessBox->addItem ( tr ( "XDMCP" ) );
     sessBox->addItem ( tr ( "Connect to local desktop" ) );
@@ -221,6 +238,7 @@ SessionWidget::SessionWidget ( QString id, ONMainWindow * mw,
 #ifndef Q_WS_HILDON
     sessLay->addLayout ( slay );
     sessLay->addLayout ( ilay );
+    sessLay->addLayout ( pathLay );
     if ( !miniMode )
         sessLay->addSpacing ( 15 );
     sessLay->addWidget ( sgb );
@@ -271,6 +289,7 @@ SessionWidget::SessionWidget ( QString id, ONMainWindow * mw,
     connect ( proxyType, SIGNAL ( buttonClicked(int)) ,this,SLOT ( slot_proxyType()));
     connect (cbProxy, SIGNAL(clicked(bool)), this, SLOT(slot_proxyOptions()));
     connect (cbProxySameUser, SIGNAL(clicked(bool)), this, SLOT(slot_proxySameLogin()));
+    connect ( pathButton, SIGNAL(clicked(bool)), this, SLOT(slot_openFolder()));
 
     readConfig();
 }
@@ -508,10 +527,24 @@ void SessionWidget::readConfig()
 {
 
     X2goSettings st ( "sessions" );
-    sessName->setText (
-        st.setting()->value (
-            sessionId+"/name",
-            ( QVariant ) tr ( "New session" ) ).toString().trimmed() );
+    QString name=st.setting()->value (
+                     sessionId+"/name",
+                     ( QVariant ) tr ( "New session" ) ).toString().trimmed();
+
+    QStringList tails=name.split("/",QString::SkipEmptyParts);
+    QString path;
+    if(tails.count()>0)
+    {
+        name=tails.last();
+        tails.pop_back();
+        path=tails.join("/")+"/";
+    }
+    lPath->setText(path);
+    if(newSession)
+        lPath->setText(parent->getSessionExplorer()->getCurrentPath()+"/");
+
+    sessName->setText (name);
+
     sessIcon=st.setting()->value (
                  sessionId+"/icon",
                  ( QVariant ) ":icons/128x128/x2gosession.png" ).toString().trimmed();
@@ -780,8 +813,11 @@ void SessionWidget::saveSettings()
 {
 
     X2goSettings st ( "sessions" );
+
+    QString normPath=(lPath->text()+"/"+sessName->text()).split("/",QString::SkipEmptyParts).join("/");
+
     st.setting()->setValue ( sessionId+"/name",
-                             ( QVariant ) sessName->text().trimmed() );
+                             ( QVariant ) normPath.trimmed() );
     st.setting()->setValue ( sessionId+"/icon",
                              ( QVariant ) sessIcon );
     st.setting()->setValue ( sessionId+"/host",
@@ -904,3 +940,12 @@ void SessionWidget::slot_krbChecked()
 {
     cbKrbDelegation->setEnabled(cbKrbLogin->isChecked());
 }
+
+void SessionWidget::slot_openFolder()
+{
+    FolderExplorer explorer(lPath->text(), parent->getSessionExplorer(), this);
+    if(explorer.exec()==QDialog::Accepted)
+    {
+        lPath->setText(explorer.getCurrentPath());
+    }
+}
