@@ -35,7 +35,7 @@ class SessionWidget : public ConfigWidget
 {
     Q_OBJECT
 public:
-    SessionWidget ( QString id, ONMainWindow * mv,
+    SessionWidget ( bool newSession, QString id, ONMainWindow * mv,
                     QWidget * parent = 0, Qt::WindowFlags f = 0 );
     ~SessionWidget();
     void setDefaults();
@@ -51,6 +51,7 @@ private slots:
     void slot_proxySameLogin();
     void slot_proxyGetKey();
     void slot_krbChecked();
+    void slot_openFolder();
 public slots:
 #ifdef Q_OS_LINUX
     void slot_rdpDirectClicked();
@@ -58,11 +59,13 @@ public slots:
 #endif
 
 private:
-    enum {KDE,GNOME,LXDE,XFCE,MATE,UNITY,RDP,XDMCP,SHADOW,OTHER,APPLICATION,PUBLISHED};
+    enum {KDE,GNOME,LXDE,XFCE,MATE,UNITY,CINNAMON,TRINITY,OPENBOX,ICEWM,RDP,XDMCP,SHADOW,OTHER,APPLICATION,PUBLISHED};
     QLineEdit* sessName;
     QLineEdit* uname;
     QLineEdit* server;
     QSpinBox* sshPort;
+    ONMainWindow* parent;
+    bool newSession;
 #ifdef Q_OS_LINUX
     QSpinBox* rdpPort;
 #endif
@@ -81,6 +84,7 @@ private:
     QLabel* leCmdIp;
     QLabel* lPort;
     QLabel* lKey;
+    QLabel* lPath;
     QPushButton* pbAdvanced;
     QString rdpOptions;
     QString rdpServer;
