@@ -518,7 +518,10 @@ void SshMasterConnection::run()
     }
 
 #ifdef Q_OS_WIN
-    ssh_options_set ( my_ssh_session, SSH_OPTIONS_SSH_DIR, (mainWnd->getHomeDirectory()+"/ssh").toAscii());
+    ssh_options_set ( my_ssh_session, SSH_OPTIONS_SSH_DIR, (mainWnd->getHomeDirectory()+"/ssh").toLocal8Bit());
+#ifdef DEBUG
+    x2goDebug<<"setting SSH DIR to "<<(mainWnd->getHomeDirectory()+"/ssh").toLocal8Bit();
+#endif
     if (kerberos)
     {
         parseKnownHosts();
@@ -625,12 +628,17 @@ void SshMasterConnection::run()
 #endif
         return;
     }
-    ssh_options_set ( my_ssh_session, SSH_OPTIONS_USER, user.toAscii() );
-#ifdef Q_OS_WIN
-    ssh_options_set ( my_ssh_session, SSH_OPTIONS_SSH_DIR, (mainWnd->getHomeDirectory()+"/ssh").toAscii());
 
+#ifdef Q_OS_WIN
+    ssh_options_set ( my_ssh_session, SSH_OPTIONS_USER, user.toLocal8Bit() );
+#else
+    ssh_options_set ( my_ssh_session, SSH_OPTIONS_USER, user.toAscii() );
+#endif
+
+#ifdef Q_OS_WIN
+    ssh_options_set ( my_ssh_session, SSH_OPTIONS_SSH_DIR, (mainWnd->getHomeDirectory()+"/ssh").toLocal8Bit());
 #ifdef DEBUG
-    x2goDebug<<"setting SSH DIR to "<<mainWnd->getHomeDirectory()+"/ssh";
+    x2goDebug<<"setting SSH DIR to "<<(mainWnd->getHomeDirectory()+"/ssh").toLocal8Bit();
 #endif
 #endif
 
