@@ -324,7 +324,15 @@
     </message>
     <message>
         <source>&amp;Settings</source>
-        <translation>&amp;Préférences</translation>
+        <translation type="obsolete">&amp;Préférences</translation>
+    </message>
+    <message>
+        <source>&amp;Input/Output</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>&amp;Media</source>
+        <translation type="unfinished"></translation>
     </message>
 </context>
 <context>
@@ -426,7 +434,7 @@
     </message>
     <message>
         <source>&amp;Settings</source>
-        <translation>&amp;Préférences</translation>
+        <translation type="obsolete">&amp;Préférences</translation>
     </message>
     <message>
         <source>&amp;Shared folders</source>
@@ -448,6 +456,14 @@
         <source>Session preferences - </source>
         <translation type="unfinished">Préférences de session - </translation>
     </message>
+    <message>
+        <source>&amp;Input/Output</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>&amp;Media</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>ExportDialog</name>
@@ -481,6 +497,72 @@
         <translation>Choisir un dossier</translation>
     </message>
 </context>
+<context>
+    <name>FolderButton</name>
+    <message>
+        <source>Sessions folder</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
+<context>
+    <name>FolderExplorer</name>
+    <message>
+        <source>Folders</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Create New Folder</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Rename Folder...</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Change Icon...</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Delete Folder...</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Open picture</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Pictures</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>X2Go Client</source>
+        <translation type="unfinished">X2Go Client</translation>
+    </message>
+    <message>
+        <source>Folder Name:</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Error</source>
+        <translation type="unfinished">Erreur</translation>
+    </message>
+    <message>
+        <source>Unable to remove &quot;</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>&quot;. Folder is not empty. Please remove content of folder and try again.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Delete folder &quot;</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>New Folder</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
 <context>
     <name>HelpDialog</name>
     <message>
@@ -618,6 +700,42 @@ Public key hash: </source>
         <translation type="unfinished"></translation>
     </message>
 </context>
+<context>
+    <name>MediaWidget</name>
+    <message>
+        <source>Sound</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Enable sound support</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Start sound daemon</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Use running sound daemon</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Use SSH port forwarding to tunnel
+sound system connections through firewalls</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Use default sound port</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Sound port:</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Client side printing support</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
 <context>
     <name>ONMainWindow</name>
     <message>
@@ -847,23 +965,19 @@ Public key hash: </source>
     </message>
     <message>
         <source>Create session icon on desktop</source>
-        <translation>Créer une icone de session sur le bureau</translation>
+        <translation type="obsolete">Créer une icone de session sur le bureau</translation>
     </message>
     <message>
         <source>Desktop icons can be configured not to show x2goclient (hidden mode). If you like to use this feature you&apos;ll need to configure login by a gpg key or gpg smart card.
 
 Use x2goclient hidden mode?</source>
-        <translation>Les icones de bureau peuvent être configurées pour ne pas afficher X2Go Client (mode caché). Si vous voulez utiliser cette fonctionnalité, vous aurez besoin de configurer l&apos;identification par clef GPG ou par Smart Card GPG.
+        <translation type="obsolete">Les icones de bureau peuvent être configurées pour ne pas afficher X2Go Client (mode caché). Si vous voulez utiliser cette fonctionnalité, vous aurez besoin de configurer l&apos;identification par clef GPG ou par Smart Card GPG.
 
 Utiliser le mode caché de X2Go Client ?</translation>
     </message>
     <message>
         <source>New Session</source>
-        <translation>Nouvelle session</translation>
-    </message>
-    <message>
-        <source>X2Go Link to session </source>
-        <translation type="unfinished"></translation>
+        <translation type="obsolete">Nouvelle session</translation>
     </message>
     <message>
         <source>X2Go sessions not found</source>
@@ -871,7 +985,7 @@ Utiliser le mode caché de X2Go Client ?</translation>
     </message>
     <message>
         <source>Are you sure you want to delete this session?</source>
-        <translation>Êtes vous sûr de vouloir effacer cette session ?</translation>
+        <translation type="obsolete">Êtes vous sûr de vouloir effacer cette session ?</translation>
     </message>
     <message>
         <source>KDE</source>
@@ -1140,10 +1254,6 @@ Unsaved documents will be lost</source>
         <source>wrong value for argument&quot;--pack&quot;</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>Options</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Available pack methodes:</source>
         <translation type="unfinished"></translation>
@@ -1302,12 +1412,6 @@ Please update to a newer x2goserver package</source>
         <source>Only my desktops</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>sshd not started, you&apos;ll need sshd for printing and file sharing
-you can install sshd with
-&lt;b&gt;sudo apt-get install openssh-server&lt;/b&gt;</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Restore toolbar</source>
         <translation type="unfinished"></translation>
@@ -1444,10 +1548,6 @@ you can install sshd with
         <source>Error getting window geometry (window closed)?</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>Show session tray icon when running</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>This can be an indication of a man-in-the-middle attack.
 Somebody might be eavesdropping on you.
@@ -1472,6 +1572,69 @@ Do you want to terminate the connection?
         <source>Verification code:</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Help</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Pack Methodes</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Option is not availabel in this build</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Changelog</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Git Info</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>SSH Error</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>SSH daemon could not be started.
+
+You&apos;ll need SSH daemon for printing and file sharing.
+
+Normally, this should not happen as X2Go Client for 
+Windows ships its internal sshd.exe.
+
+If you see this message, please report a bug against
+the X2Go bugtracker.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>SSH daemon is not running.
+
+You&apos;ll need SSH daemon for printing and file sharing
+
+Please ask your system administrator to provide the SSH
+service on your computer.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>SSH daemon failed to open the application&apos;s public host key.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>SSH daemon failed to open the application&apos;s public key
+used for exporting folders and printers.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>SSH daemon failed to open the application&apos;s
+authoized_keys file.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>wrong value for argument&quot;--clipboard&quot;</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>PrintDialog</name>
@@ -1726,6 +1889,41 @@ lpr -P hp_laserjet</source>
         <translation type="unfinished"></translation>
     </message>
 </context>
+<context>
+    <name>SessionExplorer</name>
+    <message>
+        <source>Back</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Create session icon on desktop</source>
+        <translation type="unfinished">Créer une icone de session sur le bureau</translation>
+    </message>
+    <message>
+        <source>Desktop icons can be configured not to show x2goclient (hidden mode). If you like to use this feature you&apos;ll need to configure login by a gpg key or gpg smart card.
+
+Use x2goclient hidden mode?</source>
+        <translation type="unfinished">Les icones de bureau peuvent être configurées pour ne pas afficher X2Go Client (mode caché). Si vous voulez utiliser cette fonctionnalité, vous aurez besoin de configurer l&apos;identification par clef GPG ou par Smart Card GPG.
+
+Utiliser le mode caché de X2Go Client ?</translation>
+    </message>
+    <message>
+        <source>Show session tray icon when running</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>New Session</source>
+        <translation type="unfinished">Nouvelle session</translation>
+    </message>
+    <message>
+        <source>X2Go Link to session </source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Are you sure you want to delete this session?</source>
+        <translation type="unfinished">Êtes vous sûr de vouloir effacer cette session ?</translation>
+    </message>
+</context>
 <context>
     <name>SessionManageDialog</name>
     <message>
@@ -1932,6 +2130,10 @@ lpr -P hp_laserjet</source>
         <source>Delegation of GSSAPI credentials to the server</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Path:</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>SettingsWidget</name>
@@ -1943,10 +2145,6 @@ lpr -P hp_laserjet</source>
         <source>&amp;Keyboard</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>Sound</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>RDP Client</source>
         <translation type="unfinished"></translation>
@@ -1995,35 +2193,6 @@ lpr -P hp_laserjet</source>
         <source>&amp;Identify all displays</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>Enable sound support</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Start sound daemon</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Use running sound daemon</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Use SSH port forwarding to tunnel
-sound system connections through firewalls</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Use default sound port</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Sound port:</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Client side printing support</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Additional parameters:</source>
         <translation type="unfinished"></translation>
@@ -2068,6 +2237,26 @@ sound system connections through firewalls</source>
         <source>Variant: </source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>&amp;Clipboard Mode</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Bidirectional copy and paste</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Copy and paste from client to server</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Copy and paste from server to client</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Disable clipboard completely</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>ShareWidget</name>
